==> react-daily-components-0.4.9.tgz: package/lib/esm/components/base/ContainerBase/index.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
import styled from "@emotion/styled";
import { getColorByStatus } from "../../../utilities/css";
import { TRANSITION_NORMAL } from "../../../constants/css";
import { OUT_SHADOW, VIRTUAL_ELEMENT } from "../../../constants/css";
export var ContainerBase = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  display: flex;\n  align-items: center;\n  position: relative;\n  height: 50px;\n  border: 1px solid;\n  border-radius: 4px;\n  border-color: ", ";\n  box-shadow: ", ";\n  transition: border ", "s ease-in-out,\n    box-shadow ", "s ease-in-out;\n"], ["\n  display: flex;\n  align-items: center;\n  position: relative;\n  height: 50px;\n  border: 1px solid;\n  border-radius: 4px;\n  border-color: ", ";\n  box-shadow: ", ";\n  transition: border ", "s ease-in-out,\n    box-shadow ", "s ease-in-out;\n"])), function (props) { return getColorByStatus(props); }, function (_a) {
    var active = _a.active;
    return (active ? OUT_SHADOW : "initial");
}, TRANSITION_NORMAL, TRANSITION_NORMAL);
export var ContainerAbsoluteBase = styled.div(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  &::after {\n    ", ";\n    border: 1px solid;\n    border-radius: 4px;\n    border-color: ", ";\n    box-shadow: ", ";\n    transition: border ", "s ease-in-out,\n      box-shadow ", "s ease-in-out;\n  }\n"], ["\n  &::after {\n    ", ";\n    border: 1px solid;\n    border-radius: 4px;\n    border-color: ", ";\n    box-shadow: ", ";\n    transition: border ", "s ease-in-out,\n      box-shadow ", "s ease-in-out;\n  }\n"])), VIRTUAL_ELEMENT, function (props) { return getColorByStatus(props); }, function (_a) {
    var active = _a.active;
    return (active ? OUT_SHADOW : "initial");
}, TRANSITION_NORMAL, TRANSITION_NORMAL);
var templateObject_1, templateObject_2;

==> react-daily-components-0.5.3.tgz: package/lib/esm/components/base/ContainerBase/index.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
import styled from "@emotion/styled";
import { getColorByStatus } from "../../../utilities/css";
import { TRANSITION_NORMAL } from "../../../constants/css";
import { OUT_SHADOW, VIRTUAL_ELEMENT } from "../../../constants/css";
export var ContainerBase = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  display: flex;\n  align-items: center;\n  position: relative;\n  padding: 0 10px 0 0;\n  height: 50px;\n  border: 1px solid;\n  border-radius: 4px;\n  border-color: ", ";\n  box-shadow: ", ";\n  transition: border ", "s ease-in-out,\n    box-shadow ", "s ease-in-out;\n"], ["\n  display: flex;\n  align-items: center;\n  position: relative;\n  padding: 0 10px 0 0;\n  height: 50px;\n  border: 1px solid;\n  border-radius: 4px;\n  border-color: ", ";\n  box-shadow: ", ";\n  transition: border ", "s ease-in-out,\n    box-shadow ", "s ease-in-out;\n"])), function (props) { return getColorByStatus(props); }, function (_a) {
    var active = _a.active;
    return (active ? OUT_SHADOW : "initial");
}, TRANSITION_NORMAL, TRANSITION_NORMAL);
export var ContainerAbsoluteBase = styled.div(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  &::after {\n    ", ";\n    border: 1px solid;\n    border-radius: 4px;\n    border-color: ", ";\n    box-shadow: ", ";\n    transition: border ", "s ease-in-out,\n      box-shadow ", "s ease-in-out;\n  }\n"], ["\n  &::after {\n    ", ";\n    border: 1px solid;\n    border-radius: 4px;\n    border-color: ", ";\n    box-shadow: ", ";\n    transition: border ", "s ease-in-out,\n      box-shadow ", "s ease-in-out;\n  }\n"])), VIRTUAL_ELEMENT, function (props) { return getColorByStatus(props); }, function (_a) {
    var active = _a.active;
    return (active ? OUT_SHADOW : "initial");
}, TRANSITION_NORMAL, TRANSITION_NORMAL);
var templateObject_1, templateObject_2;
